from django.conf import settings
from apps.reporting.variants.pentest_report import PentestReport


class Report(PentestReport):
    def get_context(self):
        context = {"variant": self, "REPORT_COMPANY_INFORMATION": settings.REPORT_COMPANY_INFORMATION}
        if self.vulnerability:
            context["vulnerability"] = self.vulnerability
        return context
