@page {
  size: a4 portrait;
  margin: 3cm 1cm 2cm 1cm;

  @top-right {
      content: " ";
      background: url(file://images/logo-with-text.svg);
      background-size: 100%;
      background-repeat: no-repeat;
      height: 12mm;
      width: 53mm;
      margin-bottom: 8mm;
      margin-right: -6mm;
  }

}

@page :blank {
  @top-left {
    background: none;
    content: "";
  }

  @top-center {
    content: none;
  }

  @top-right {
    content: none;
  }
}

@page no-chapter {
  @top-left {
    background: none;
    content: none;
  }

  @top-center {
    content: none !important;
  }

  @top-right {
    content: none !important;
  }
}

@page chapter {
  background: #2c3e50;

  @top-left {
    content: none;
  }

  @top-center {
    content: none;
  }

  @top-right {
    content: none;
  }
}

@page cover-page {
  background: url(file://images/cover.png) no-repeat center;
  background-size: cover;
  margin: 0;
}

html {
  font-family: "Fira Sans", sans-serif;
  color: #393939;
  font-size: 12px;
  font-weight: 300;
  line-height: 1.5;
}

h1 {
  break-before: always;
  font-size: 26px;
  string-set: heading content();
}

h2 {
  font-size: 22px;

  /*margin-bottom: 1.0 em;*/
}

h3 {
  font-size: 18px;
}

h4, h5 {
  font-size: 16px;
}

#cover {
  align-content: space-between;
  display: flex;
  flex-wrap: wrap;
  height: 297mm;

  h1 {
    color: #c6c9cb;
    font-size: 32pt;
    margin: 8cm 2cm 0 2cm;
    page: cover-page;
    width: 100%;
  }

  h2 {
    color: #c6c9cb;
    font-size: 28pt;
    margin: -5cm 2cm 0 2cm;
    page: no-chapter;
    width: 100%;
  }

  h3 {
    color: #c6c9cb;
    font-size: 24pt;
    margin: -7cm 2cm 0 2cm;
    page: no-chapter;
    width: 100%;
  }
}

#cover-footer {
  color: #c6c9cb;
  flex: 1 50%;
  margin-bottom: 1cm;
  margin-left: 1cm;

  a {
    color: #c6c9cb;
  }
}

.chapter {
  /*border-bottom: 1px solid black;*/
  margin-top: -1cm;
}

table {
  &.vulnerability-detail-table {
    width: 100%;
    border-collapse: collapse;

    td, th {
      border: 1px solid black;
      border-collapse: collapse;
      padding: 5px;
      text-align: left;
    }
  }

  &.table-bordered {
    width: 100%;
    border-collapse: collapse;

    td, th {
      border: 1px solid black;
      border-collapse: collapse;
      padding: 5px;
      text-align: left;
    }
  }
}



.float-start {
  float: left;
}

.float-end {
  float: right;
}

.h-100 {
  height: 100%;
}

.border-right-1 {
  border-right: 1px solid black;
}

.border-1 {
  border: 1px solid black;
}

.contact-card {
  border: 0.5px solid black;
  padding: 10px;
  box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2);

  /* this adds the "card" effect */
}

/* Float four columns side by side */

.column {
  float: left;
  width: 47%;
  padding: 0 10px;
}

.mb-3 {
  margin-bottom: 1rem !important;
}

/* Remove extra left and right margins, due to padding in columns */

.row {
  margin: 0 -10px;

  &:after {
    content: "";
    display: table;
    clear: both;
  }
}

.text-critical {
  color: $critical-color;
}

.text-high {
  color: $high-color;
}

.text-medium {
  color: $medium-color;
}

.text-low {
  color: $low-color;
}

.text-informational {
  color: $informational-color;
}

.text-critical a, .text-high a, .text-medium a, .text-low a, .text-info a, .text-informational a {
  color: inherit;
  text-decoration: inherit;
}

pre {
  word-wrap: normal;
  max-width: 100%;
  white-space: pre-wrap;
  background-color: #f8f8f8;
  border-radius: 5px;
  border: 1px solid #c6c9cb;
  padding: 8px 15px;
  word-break: break-all;
}

code {
  word-wrap: normal;
  max-width: 100%;
  word-break: break-all;

}

.page-break {
  page-break-before: always;
}

.codehilite .linenos {
  padding-right: 20px;
}

.draft {
  z-index: -2;
  background: url(file://images/draft.png);
  background-repeat: no-repeat;
  background-position: center;
  background-size: contain;
}

#severity-chart {
  margin-left: auto;
  margin-right: auto;
  display: block;
  height: 8cm;
  max-width: 8cm;
}

.chart-container {
  display: flex;
  justify-content: center;
}

#categories-chart {}


/* Colors */
.color-white {
  color: $white;
}

.bg-primary {
  background-color: $primary;
}
