
.change-history-table {
  width: 100%;
  border-collapse: collapse;

  td {
    border-bottom: 1px solid $table-border-color;
    padding: 8px;
  }

  th {
    border-bottom: 1px solid $table-border-color;
    padding: 8px;
    padding-bottom: 12px;
    padding-top: 12px;
    text-align: left;
    background-color: $primary;
    color: $white;
  }
}