@font-face {
    font-family: Fira Sans;
    font-weight: 400;
    src: url(file://fonts/firasans-regular.otf);
}

@font-face {
    font-family: Fira Sans;
    font-style: italic;
    font-weight: 400;
    src: url(file://fonts/firasans-italic.otf);
}

@font-face {
    font-family: Fira Sans;
    font-weight: 300;
    src: url(file://fonts/firasans-light.otf);
}

@font-face {
    font-family: Fira Sans;
    font-style: italic;
    font-weight: 300;
    src: url(file://fonts/firasans-lightitalic.otf);
}

@font-face {
    font-family: Fira Sans;
    font-weight: 700;
    src: url(file://fonts/firasans-bold.otf);
}
