{% load i18n %}

<article id="cover">
    <h1>{{ release.report.get_report_title }}</h1>
    <h2>{{ project.name }}</h2>
    <h3>{{ project.client.name }}</h3>
    <table id="cover-footer">
        <tr>
            <td>{% trans 'Author' %}:</td>
            <td>{{ release.report.author }}</td>
        </tr>
        <tr>
            <td>{% trans 'Version' %}:</td>
            <td>{{ release.report.get_current_version }}</td>
        </tr>
        <tr>
            <td>{% trans 'Date' %}:</td>
            <td>{% now "jS F Y" %}</td>
        <tr>
            <td>{% trans 'Generator' %}:</td>
            <td><a href="https://vulnman.github.io" rel="noopener nofollow">VULNMAN</a></td>
        </tr>
    </table>

</article>