
$critical-color: #9c1720;
$high-color: #d13c0f;
$medium-color: #e8971e;
$low-color: #2075f5;
$informational-color: #059D1D;

$primary: #2c3e50;
$white: #ddd;

/* Tables */
$table-border-color: black;
