{% load markdown %}
{% load vulns %}
{% load i18n %}

{% load markdown %}
{% load i18n %}

<article id="change-history" class="chapter">
    <h1 class="chapter-title" id="change-history-title">{% trans "Change History" %}</h1>

    <section>
        <table class="change-history-table">
            <thead>
            <tr>
                <th>{% trans 'Version' %}</th>
                <th>{% trans 'Change' %}</th>
                <th>{% trans 'User' %}</th>
                <th>{% trans 'Date' %}</th>
            </tr>
            </thead>
            <tbody>
            {% for version in release.report.reportversion_set.all %}
                <tr>
                    <td>{{ version.version }}</td>
                    <td>{{ version.get_change_display }}</td>
                    <td>{{ version.user.username }}</td>
                    <td>{{ version.date }}</td>
                </tr>
            {% endfor %}
            </tbody>
        </table>
    </section>
</article>
