<html>
<head>
    <meta charset="utf-8">
    <title>{{ vulnerability.template.vulnerability_id }}</title>
    <meta name="description" content="{{ vulnerability.template.vulnerability_id }}">

    <style>
        @page {
            @bottom-left {
                font-size: 10px;
                content: "Confidential";
                margin-top: -5px;

            }

            @bottom-center {
                content: "{{ REPORT_COMPANY_INFORMATION.name }}";
                font-size: 10px;
                margin-top: -5px;
            }

            @bottom-right {
                font-size: 10px;
                content: counter(page) ' / ' counter(pages);
                margin-top: -5px;
            }
        }
    </style>
</head>

<body>
    {% include './pages/single_vulnerability.html' %}
</body>
</html>
