@page no-chapter {
    @top-left {
        background: none;
        content: none
    }
    @top-center {
        content: none !important
    }
    @top-right {
        content: none !important
    }
}

@page {
    @bottom-right {
        font-size: 10px;
        content: counter(page) ' / ' counter(pages);
        margin-top: -5px;
    }
}