{% load i18n %}

<article id="contents">
    <h2>{% trans "Table of contents" %}</h2>

    <h3>{% trans "Overview" %}</h3>
    <ul>
        <li><a href="#contacts-title"></a></li>
        <li><a href="#introduction-title"></a></li>
        <li><a href="#scope-title"></a></li>
    </ul>

    <h3>{% trans "Management Summary" %}</h3>
    <ul>
        <li><a href="#vulnerability-title"></a></li>
        <li><a href="#mgmt-summary-evaluation-title"></a></li>
        <li><a href="#mgmt-summary-recommendation-title"></a></li>
    </ul>

    <h3>{% trans "Vulnerability Details" %}</h3>
    <ul>
        <li><a href="#vulnerability-listing-title"></a></li>
    </ul>

</article>