{% load markdown %}
{% load i18n %}

<article id="introduction" class="chapter">
    <h1 id="introduction-title">{% trans 'Introduction' %}</h1>
</article>

<article>
    <section class="page-content">
        <p>
            {% blocktrans trimmed %}
                This report contains the results of a vulnerability assessment of your systems.
            {% endblocktrans %}
        </p>
        <p>
            {% blocktrans trimmed %}
                The report includes a management summary that summarizes the findings and provides a brief
                recommendation for remediation of the vulnerabilities.
            {% endblocktrans %}
        <p>
            {% blocktrans trimmed %}
                To reproduce the vulnerabilities, they are described with technical details at the end of the report.
                An assessment regarding criticality is provided.
            {% endblocktrans %}
        </p>
    </section>
</article>